==> ejc-metadata-api-3.0.0-20200420.034248-1-sources.jar: com/ejianc/foundation/metadata/vo/MdRelationVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

public class MdRelationVO extends BaseVO {

	private Long id; //主键ID
	
	private String relationName;// 关系名称

	private String displayName;// 关系显示名称

	private Long sourceEntityId;// 来源实体ID
	
	private String sourceEntityName;// 来源实体name

	private Long sourceAttributeId;// 来源实体属性id
	
	private String sourceAttributeName;// 来源实体name

	private Long targetEntityId;// 目标实体id
	
	private String targetEntityName;// 来源实体name

	private Long targetAttributeId;// 目标实体属性id
	
	private String targetAttributeName;// 来源实体name

	private Long projectId;// 项目id

	private Integer type;// 关系类型
	
	private Long tenantId; //租户名称
	private Integer dr;
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getRelationName() {
		return relationName;
	}
	public void setRelationName(String relationName) {
		this.relationName = relationName;
	}
	public String getDisplayName() {
		return displayName;
	}
	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}
	public Long getSourceEntityId() {
		return sourceEntityId;
	}
	public void setSourceEntityId(Long sourceEntityId) {
		this.sourceEntityId = sourceEntityId;
	}
	public Long getSourceAttributeId() {
		return sourceAttributeId;
	}
	public void setSourceAttributeId(Long sourceAttributeId) {
		this.sourceAttributeId = sourceAttributeId;
	}
	public Long getTargetEntityId() {
		return targetEntityId;
	}
	public void setTargetEntityId(Long targetEntityId) {
		this.targetEntityId = targetEntityId;
	}
	public Long getTargetAttributeId() {
		return targetAttributeId;
	}
	public void setTargetAttributeId(Long targetAttributeId) {
		this.targetAttributeId = targetAttributeId;
	}
	public Long getProjectId() {
		return projectId;
	}
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}
	public Integer getType() {
		return type;
	}
	public void setType(Integer type) {
		this.type = type;
	}
	public Long getTenantId() {
		return tenantId;
	}
	public void setTenantId(Long tenantId) {
		this.tenantId = tenantId;
	}
	public Integer getDr() {
		return dr;
	}
	public void setDr(Integer dr) {
		this.dr = dr;
	}
	public String getSourceEntityName() {
		return sourceEntityName;
	}
	public void setSourceEntityName(String sourceEntityName) {
		this.sourceEntityName = sourceEntityName;
	}
	public String getSourceAttributeName() {
		return sourceAttributeName;
	}
	public void setSourceAttributeName(String sourceAttributeName) {
		this.sourceAttributeName = sourceAttributeName;
	}
	public String getTargetEntityName() {
		return targetEntityName;
	}
	public void setTargetEntityName(String targetEntityName) {
		this.targetEntityName = targetEntityName;
	}
	public String getTargetAttributeName() {
		return targetAttributeName;
	}
	public void setTargetAttributeName(String targetAttributeName) {
		this.targetAttributeName = targetAttributeName;
	}
	
}

==> ejc-metadata-api-3.0.0-20200516.014020-25-sources.jar: com/ejianc/foundation/metadata/vo/MdRelationVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdRelationVO extends BaseVO {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private Long id; //主键ID
	
	private String relationName;// 关系名称

	private String displayName;// 关系显示名称

	private Long sourceEntityId;// 来源实体ID
	
	private String sourceEntityName;// 来源实体name

	private Long sourceAttributeId;// 来源实体属性id
	
	private String sourceAttributeName;// 来源实体name

	private Long targetEntityId;// 目标实体id
	
	private String targetEntityName;// 来源实体name

	private Long targetAttributeId;// 目标实体属性id
	
	private String targetAttributeName;// 来源实体name

	private Long projectId;// 项目id

	private Integer type;// 关系类型
	
	private Long tenantId; //租户名称
	private Integer dr;
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getRelationName() {
		return relationName;
	}
	public void setRelationName(String relationName) {
		this.relationName = relationName;
	}
	public String getDisplayName() {
		return displayName;
	}
	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}
	public Long getSourceEntityId() {
		return sourceEntityId;
	}
	public void setSourceEntityId(Long sourceEntityId) {
		this.sourceEntityId = sourceEntityId;
	}
	public Long getSourceAttributeId() {
		return sourceAttributeId;
	}
	public void setSourceAttributeId(Long sourceAttributeId) {
		this.sourceAttributeId = sourceAttributeId;
	}
	public Long getTargetEntityId() {
		return targetEntityId;
	}
	public void setTargetEntityId(Long targetEntityId) {
		this.targetEntityId = targetEntityId;
	}
	public Long getTargetAttributeId() {
		return targetAttributeId;
	}
	public void setTargetAttributeId(Long targetAttributeId) {
		this.targetAttributeId = targetAttributeId;
	}
	public Long getProjectId() {
		return projectId;
	}
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}
	public Integer getType() {
		return type;
	}
	public void setType(Integer type) {
		this.type = type;
	}
	public Long getTenantId() {
		return tenantId;
	}
	public void setTenantId(Long tenantId) {
		this.tenantId = tenantId;
	}
	public Integer getDr() {
		return dr;
	}
	public void setDr(Integer dr) {
		this.dr = dr;
	}
	public String getSourceEntityName() {
		return sourceEntityName;
	}
	public void setSourceEntityName(String sourceEntityName) {
		this.sourceEntityName = sourceEntityName;
	}
	public String getSourceAttributeName() {
		return sourceAttributeName;
	}
	public void setSourceAttributeName(String sourceAttributeName) {
		this.sourceAttributeName = sourceAttributeName;
	}
	public String getTargetEntityName() {
		return targetEntityName;
	}
	public void setTargetEntityName(String targetEntityName) {
		this.targetEntityName = targetEntityName;
	}
	public String getTargetAttributeName() {
		return targetAttributeName;
	}
	public void setTargetAttributeName(String targetAttributeName) {
		this.targetAttributeName = targetAttributeName;
	}
	
}
